import * as pluginManager from './toolbar_plus/tool-plugin-manager.js';

(($, Drupal, once) => {

  Drupal.ToolbarPlus = {};

  pluginManager.default($, Drupal, once);

  /**
   * Toolbar Plus Edit Mode.
   */
  Drupal.behaviors.ToolbarPlusEditMode = {
    attach: (context, settings) => {
      once('ToolbarPlusToggleEditMode', '#toggle-edit-mode', context).forEach(toggleEditModeButton => {

        const activeTool = localStorage.getItem('toolbar_plus.tool.active');

        // Enable active tools on page load.
        if (sessionStorage.getItem('editMode') === 'enabled' && activeTool !== null) {
          Drupal.behaviors.ToolbarPlusEditMode.changeMouse(activeTool);
          Drupal.ToolbarPlus.PluginManager.getPlugin(activeTool).enable();
        }

        // Listen for tool activation clicks.
        document.querySelectorAll('.toolbar-plus-button').forEach((toolButton) => {
          toolButton.onclick = (event) => {
            const activeTool = localStorage.getItem('toolbar_plus.tool.active') ?? 'pointer';
            const nextTool = event.currentTarget.dataset.tool;

            Drupal.ToolbarPlus.PluginManager.getPlugin(activeTool).disable().then(() => {
              Drupal.behaviors.ToolbarPlusEditMode.changeMouse(nextTool);
              Drupal.ToolbarPlus.PluginManager.getPlugin(nextTool).enable();
              localStorage.setItem('toolbar_plus.tool.active', nextTool);
              document.cookie="activeTool=" + nextTool + "; path=/";
              sessionStorage.setItem('editMode', 'enabled');
            });
          }
        });

        // Enable and disable edit mode.
        toggleEditModeButton.onclick = e => {
          e.preventDefault();
          const toolbar = document.querySelector("#toolbar-plus");
          if (toolbar.classList.contains('toolbar-plus-hidden')) {
            Drupal.behaviors.ToolbarPlusEditMode.EnableEditMode();
          } else {
            Drupal.behaviors.ToolbarPlusEditMode.DisableEditMode();
          }
        }
      });
    },
    EnableEditMode: () => {
      // Hide the other navigation items.
      Drupal.behaviors.ToolbarPlusEditMode.getOtherNavigationItems().forEach(navigationItem => {
        navigationItem.classList.add('toolbar-plus-hidden');
      });
      // Reveal the toolbar.
      const toolbar = document.querySelector("#toolbar-plus");
      const toggleEditModeButton = document.querySelector("#toggle-edit-mode");
      toggleEditModeButton.classList.add('active');
      toolbar.classList.remove('toolbar-plus-hidden');
      sessionStorage.setItem('editMode', 'enabled');
      document.cookie="editMode=enabled; path=/";
      // Reveal the top bar.
      document.querySelector('.top-bar:not(#toolbar-plus-top-bar)').classList.add('toolbar-plus-hidden');
      document.querySelector('#toolbar-plus-top-bar').classList.remove('toolbar-plus-hidden');
      // Reveal the sidebar.
      document.querySelector('.toolbar-plus-sidebar-wrapper').classList.remove('toolbar-plus-hidden');
    },
    DisableEditMode:() => {
      // Reveal the other navigation items.
      Drupal.behaviors.ToolbarPlusEditMode.getOtherNavigationItems().forEach(navigationItem => {
        navigationItem.classList.remove('toolbar-plus-hidden');
      });
      // Hide the toolbar.
      const toolbar = document.querySelector("#toolbar-plus");
      toolbar.classList.add('toolbar-plus-hidden');
      const toggleEditModeButton = document.querySelector("#toggle-edit-mode");
      toggleEditModeButton.classList.remove('active');
      Drupal.behaviors.ToolbarPlusEditMode.removeMouse();
      sessionStorage.setItem('editMode', 'disabled');
      const activeTool = localStorage.getItem('toolbar_plus.tool.active');
      Drupal.ToolbarPlus.PluginManager.getPlugin(activeTool).disable();
      document.cookie="editMode=disabled; path=/";
      // Hide the top bar.
      document.querySelector('.top-bar:not(#toolbar-plus-top-bar)').classList.remove('toolbar-plus-hidden');
      document.querySelector('#toolbar-plus-top-bar').classList.add('toolbar-plus-hidden');
      // Hide the sidebar.
      document.querySelector('.toolbar-plus-sidebar-wrapper').classList.add('toolbar-plus-hidden');
    },
    removeMouse: () => {
      document.querySelectorAll('.toolbar-plus-button.active').forEach(button => {
        document.querySelector('html').classList.remove(button.dataset.tool);
        button.classList.remove('active');
      });
    },
    changeMouse: (pluginId) => {
      Drupal.behaviors.ToolbarPlusEditMode.removeMouse();
      document.querySelector('[data-tool="' + pluginId + '"]').classList.add('active');
      document.querySelector('html').classList.add(pluginId);
      sessionStorage.setItem('mouseState', pluginId);
    },
    getOtherNavigationItems: () => {
      return document.querySelectorAll('#menu-builder .toolbar-block:not(#toolbar-plus)');
    },
  };

})(jQuery, Drupal, once);



